.. assyst ASSYST documentation master file, created by
   sphinx-quickstart on Mon Jun 23 16:38:54 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

ASSYST documentation
====================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Home <self>
   installation
   assyst
